@@ -23,7 +23,7 @@ my $ErrorCodes = {
     '423' => undef,           # Service refused, please try later. LPN105_423
     '424' => undef,           # Veuillez essayer plus tard. LPN105_424
     '506' => 'spamdetected',  # Mail rejete. Mail rejected. OFR_506 [506]
-    '510' => 'blocked',       # Veuillez essayer plus tard. service refused, please try later. LPN004_510 
+    '510' => 'blocked',       # Veuillez essayer plus tard. service refused, please try later. LPN004_510
     '513' => undef,           # Mail rejete. Mail rejected. OUK_513
     '514' => 'mesgtoobig',    # Taille limite du message atteinte
 };
@@ -34,9 +34,7 @@ sub get {
     # @return   [String]                The bounce reason for Orange, La Poste
     my $class = shift;
     my $argvs = shift // return undef;
-
-    return undef unless ref $argvs eq 'Sisimai::Data';
-    return $argvs->reason if length $argvs->reason;
+    return $argvs->reason if $argvs->reason;
 
     my $statusmesg = $argvs->diagnosticcode;
     my $reasontext = '';
